/**
 * Created by MeePwn
 * https://github.com/maybewaityou
 *
 * description:
 *
 */
import { injectable } from 'inversify';

@injectable()
export abstract class StrategyProcessor<ResultType = any> {
  public async process(): Promise<ResultType> {
    const localData = await this.loadFromDb();
    if (this.shouldFetch(localData)) {
      return this.fetchFromNetwork();
    } else {
      return localData;
    }
  }

  protected abstract loadFromDb(): Promise<ResultType>;
  protected abstract shouldFetch(data?: ResultType): boolean;
  protected abstract createService(): Promise<ResultType | Array<ResultType | any>>;

  protected processResponse(response: ResultType | Array<ResultType | any>): ResultType {
    if (response instanceof Array) {
      throw new Error('Please override this method to process many responses.');
    }
    return response;
  }

  protected abstract saveResult(data: ResultType): void;

  private async fetchFromNetwork(): Promise<ResultType> {
    const service = this.createService();
    const response = await service;
    const result = this.processResponse(response);
    this.saveResult(result);
    return Promise.resolve(result);
  }
}
