/**
 * Created by MeePwn
 * https://github.com/maybewaityou
 *
 * description:
 *
 * @header({
 *   TitleContainer: (props) => (
 *    <View style={props.style}>
 *       {props.children}
 *     </View>
 *   ),
 *   // title: 'title',
 *   title: (props) => {
 *     const { userName } = props.params;
 *     return userName;
 *   },
 *   LeftComponent: (props) => (
 *     <Button title="left" onPress={props.handleLeftPress} />
 *   ),
 * })
 *
 */
import React, { PureComponent, ComponentClass, StatelessComponent } from 'react';
import { SafeAreaView } from 'react-navigation';
import { Text, View } from 'react-native';

import styles from './style/index';
import { IHeaderConfig, TComponent } from './PropsType';

export default (config: IHeaderConfig) => (WrappedComponent: TComponent) => {
  return class extends PureComponent {
    public titleComponent = () => {
      if (config.TitleComponent) {
        return (
          <View style={styles.headerTitle}>
            <config.TitleComponent {...this.props} />
          </View>
        );
      }
      let title = '';
      if (typeof config.title === 'string') {
        title = config.title;
      } else if (typeof config.title === 'function') {
        title = config.title(this.props);
      }
      return (
        <View style={styles.headerTitle}>
          <Text style={styles.title}>{title}</Text>
        </View>
      );
    };

    public leftComponent = () =>
      config.LeftComponent ? (
        <View style={styles.headerLeft}>
          <config.LeftComponent {...this.props} />
        </View>
      ) : (
        <View style={styles.headerLeft} />
      );

    public rightComponent = () =>
      config.RightComponent ? (
        <View style={styles.headerRight}>
          <config.RightComponent {...this.props} />
        </View>
      ) : (
        <View style={styles.headerRight} />
      );

    public render() {
      const TitleContainer = config.TitleContainer || View;
      return (
        <View style={styles.container}>
          <SafeAreaView>
            <TitleContainer style={styles.header} {...this.props}>
              {this.leftComponent()}
              {this.titleComponent()}
              {this.rightComponent()}
            </TitleContainer>
          </SafeAreaView>
          <WrappedComponent {...this.props} />
        </View>
      );
    }
  };
};
