/**
 * Created by MeePwn
 * https://github.com/maybewaityou
 *
 * description:
 *
 */
import React from 'react';
import {
  StyleSheet,
  Button,
  Image,
  ImageStyle,
  Text,
  TextStyle,
  View,
  ViewStyle,
  SafeAreaView,
  TouchableOpacity,
} from 'react-native';
import { IImageStyle, ITextStyle, IViewStyle } from 'react-native-screen-adapter';
import { router } from 'mario-navigation-extension';

import { Images, Color } from '@constant';
import Toast from '../toast/index';

interface IStyle {
  container: IViewStyle;
  title: ITextStyle;
  image: IImageStyle;
  leftContainer: IViewStyle;
  rightContainer: IViewStyle;
}

function defaultBackAction() {
  router.pop();
}

export function BackArrow(props: any) {
  return (
    <TouchableOpacity activeOpacity={0.8} onPress={props.onPress || defaultBackAction}>
      <Image source={Images.back} resizeMode="contain" style={styles.image} />
    </TouchableOpacity>
  );
}

export default (props: any) => {
  const leftComponent = props.leftComponent || <BackArrow onPress={props.onBackPress} />;
  return (
    <SafeAreaView style={styles.container}>
      <View style={styles.leftContainer}>{leftComponent}</View>
      <Text style={styles.title}>{props.title}</Text>
      <View style={styles.rightContainer}>{props.rightComponent}</View>
      <Toast show={props.showToast} title={props.message} delay={props.toastDelay} onDismiss={props.onToastDismiss} />
    </SafeAreaView>
  );
};

const styles = StyleSheet.create<IStyle>({
  container: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
    width$: 375,
    backgroundColor: Color.white,
  },
  title: {
    flex: 1,
    $fontSize: '$fontSize',
    textAlign: 'center',
  },
  image: {},
  leftContainer: {
    flex: 1,
    padding: 10,
    marginLeft: 6,
  },
  rightContainer: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'flex-end',
    padding: 10,
    marginRight: 6,
  },
});
