/**
 * Created by MeePwn
 * https://github.com/maybewaityou
 *
 * description:
 *
 */
import React, { useState, useEffect } from 'react';
import {
  StyleSheet,
  Button,
  Image,
  ImageStyle,
  Text,
  TextStyle,
  View,
  ViewStyle,
  Animated,
  Platform,
} from 'react-native';
import { isIPhoneX, IImageStyle, ITextStyle, IViewStyle } from 'react-native-screen-adapter';

import { Images, Color } from '@constant';

interface IStyle {
  container: IViewStyle;
  subContainer: IViewStyle;
  title: ITextStyle;
}

export default (props: any) => {
  const visible = props.show;
  if (!visible) {
    return null;
  }

  const duration = props.duration || 350;
  let hasShown = false;
  const [opacityValue] = useState(new Animated.Value(0));

  Animated.timing(opacityValue, {
    toValue: 1,
    duration,
  }).start(() => {
    hasShown = true;
  });

  let timer: any;
  useEffect(() => {
    if (!visible) {
      return;
    }
    timer && clearTimeout(timer);
    timer = setTimeout(
      () => {
        if (!hasShown) {
          return;
        }

        Animated.timing(opacityValue, {
          toValue: 0.0,
          duration,
        }).start(() => {
          hasShown = false;

          props.onDismiss && props.onDismiss();
        });
      },
      props.delay ? duration + props.delay : duration + 3000,
    );
    return () => {
      timer && clearTimeout(timer);
    };
  }, [props.title]);

  return (
    <Animated.View style={[styles.container, { opacity: opacityValue }]}>
      <View style={styles.subContainer}>
        <Image source={Images.warning} resizeMode="contain" />
        <Text style={styles.title}>{props.title}</Text>
      </View>
    </Animated.View>
  );
};

const styles = StyleSheet.create<IStyle>({
  container: {
    justifyContent: 'center',
    alignItems: 'center',
    height$: 44,
    backgroundColor: Color.white,
    position: 'absolute',
    top: isIPhoneX() ? 44 : Platform.OS === 'android' ? 0 : 20,
    left: 10,
    right: 10,

    borderRadius: 4,

    shadowRadius: 3,
    shadowOpacity: 0.3,
    shadowOffset: { width: 0, height: 3 },
    elevation: 3,
    zIndex: 1000,
  },
  subContainer: {
    flexDirection: 'row',
  },
  title: {
    color: '#333333',
    $fontSize: '$middleFontSize',
    fontFamily: 'PingFangSC-Regular',
    marginLeft: 8,
  },
});
