/**
 * Created by MeePwn
 * https://github.com/maybewaityou
 *
 * description:
 *
 */
import { Alert } from 'react-native';
import axios, { AxiosRequestConfig } from 'axios';
import { injectable } from 'inversify';

import { Constant } from '@constant';
import { Method } from '@enum/Method';
import { ModalType } from '@enum/ModalType';
import { Context } from '@context';
import { requestHeader } from '@configs/network';
import { IRequest, IResponse } from '@task';

const instance = axios.create({
  baseURL: Constant.BASE_URL,
  timeout: Constant.TIMEOUT,
  headers: requestHeader,
});
instance.interceptors.request.use(
  (config) => {
    console.log(`== url ===>>>> ${config.url}`);
    console.log(`== params ===>>>> ${JSON.stringify(config.data || config.params)}`);
    return config;
  },
  (error) => Promise.reject(error),
);
instance.interceptors.response.use(
  (response) => {
    const url = response.config.url.replace(new RegExp(Constant.BASE_URL), '');
    console.log(`== url ===>>>> ${url}`);
    console.log(`== response ===>>>> ${JSON.stringify(response.data)}`);
    return response;
  },
  (error) => Promise.reject(error),
);

@injectable()
export class WebService {
  public async request<ReturnType = any>(
    url: string,
    params: IRequest | any = {},
    config?: AxiosRequestConfig,
  ): Promise<ReturnType> {
    const meta = params.meta || { silence: true, method: Method.POST };
    // TODO: 弹框判断
    delete params.meta;

    try {
      const request =
        meta.method === Method.GET ? instance.get(url, { params, ...config }) : instance.post(url, params);
      const response = await request;
      const json = response.data as IResponse<any>;
      // TODO: 弹框判断

      if (Context.isSuccess(json)) {
        return Promise.resolve(json.data as ReturnType);
      }
      return this.handleError(new Error(json.retMsg), { url, params, meta, config });
    } catch (err) {
      return this.handleError(err, { url, params, meta, config });
    }
  }

  /**
   * 失败公共处理
   */
  private handleError(error: Error, { url, params, meta, config }: any): Promise<any> {
    return new Promise((resolve, reject) => {
      this.failureHandler(
        error,
        { url, params, meta, config },
        () => {
          params.meta = { ...meta };
          resolve(this.request(url, params, config));
        },
        () => {
          reject(error);
        },
      );
    });
  }

  /**
   * 网络失败处理
   */
  private failureHandler(error: Error, { url, params, meta, config }: any, positiveAction: any, negativeAction: any) {
    if (meta.resend) {
      Alert.alert(meta.errorTitle || ModalType.FAILURE, `${meta.errorMessage || ''}`, [
        {
          text: '否',
          onPress: negativeAction,
        },
        {
          text: '是',
          onPress: positiveAction,
        },
      ]);
    } else {
      Alert.alert(meta.errorTitle || ModalType.FAILURE, `${meta.errorMessage || ''}`, [
        {
          text: '确定',
          onPress: negativeAction,
        },
      ]);
    }
  }
}
