/**
 * Created by MeePwn
 * https://github.com/maybewaityou
 *
 * description:
 *
 */
import { Animated, Easing, Platform } from 'react-native';

import { Color } from '@constant';

/**
 * iOS:
 * backgroundColor: '#eee',
 * 修改 node_modules/react-navigation-stack/lib/commonjs/views/StackView/StackViewTransitionConfigs.js 文件
 * 底色默认为 backgroundColor: '#eee',
 *
 * Android:
 *
 */
const containerStyle =
  Platform.OS === 'ios'
    ? {
        backgroundColor: Color.transparent,
      }
    : {
        backgroundColor: Color.transparent,
      };

function navigatorTransition() {
  return {
    containerStyle,
    transitionSpec: {
      duration: 500,
      easing: Platform.OS === 'ios' ? Easing.bezier(0.2833, 0.99, 0.31833, 0.99) : Easing.inOut(Easing.poly(4)),
      timing: Animated.timing,
    },
    screenInterpolator: (sceneProps: any) => {
      const { layout, position, scene } = sceneProps;
      const { index } = scene;

      const width = layout.initHeight;
      const translateX = position.interpolate({
        inputRange: [index - 1, index, index + 1],
        outputRange: [width, 0, 0],
      });

      const opacity = position.interpolate({
        inputRange: [index - 1, index - 0.99, index],
        outputRange: [0, 1, 1],
      });

      return { opacity, transform: [{ translateX }] };
    },
  };
}

function modalTransition() {
  return {
    containerStyle,
    transitionSpec: {
      duration: 500,
      easing: Platform.OS === 'ios' ? Easing.bezier(0.2833, 0.99, 0.31833, 0.99) : Easing.inOut(Easing.poly(4)),
      timing: Animated.timing,
    },
    screenInterpolator: (sceneProps: any) => {
      const { layout, position, scene } = sceneProps;
      const { index } = scene;

      const height = layout.initHeight;
      const translateY = position.interpolate({
        inputRange: [index - 1, index, index + 1],
        outputRange: [height, 0, 0],
      });

      const opacity = position.interpolate({
        inputRange: [index - 1, index - 0.99, index],
        outputRange: [0, 1, 1],
      });

      return { opacity, transform: [{ translateY }] };
    },
  };
}

export default {
  navigatorTransition,
  modalTransition,
};
